<?php

if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

if (!isset($_SESSION['mlm_user_id'])) {
    echo "You are not logged in.";
    exit;
}

if (!isset($_SESSION['mlm_user_id'])) {
    echo "You are not logged in.";
    exit;
}

include 'db.php';

// $mlmUserId = $_SESSION['mlm_user_id'];

// Fetch user data
$query = "SELECT `id`, `name`, `phone`, `reference_number`, `my_number`, `created_at`, `approved` FROM `MLM_users` WHERE `id` = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $mlmUserId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $referenceUserId = $user['reference_number'];
} else {
    echo "No user found with the provided ID.";
    exit;
}

// Check for users with the same phone number
$samePhoneQuery = "SELECT `id`, `name`, `phone` FROM `MLM_users` WHERE `phone` = ? AND `id` != ?";
$samePhoneStmt = $conn->prepare($samePhoneQuery);
$samePhoneStmt->bind_param("si", $user['phone'], $mlmUserId);
$samePhoneStmt->execute();
$samePhoneResult = $samePhoneStmt->get_result();
$samePhoneUsers = $samePhoneResult->fetch_all(MYSQLI_ASSOC);

// Switch user session
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['switch_user_id'])) {
    $newUserId = intval($_POST['switch_user_id']);
    $_SESSION['mlm_user_id'] = $newUserId; 
    echo "Switched to user ID: " . $_SESSION['mlm_user_id']; // Debug output
    exit; // Ensure we exit to prevent further processing
}

// Fetch user data from MLM_users
$sql_user = "SELECT name, my_number FROM MLM_users WHERE id = ?";
$userStmt = $conn->prepare($sql_user);
$userStmt->bind_param("i", $mlmUserId);
$userStmt->execute();
$result_user = $userStmt->get_result();

if ($result_user->num_rows > 0) {
    $user = $result_user->fetch_assoc();
    $user_name = $user['name'];
    $my_number = $user['my_number'];
} else {
    echo "User not found!";
    exit;
}

// Fetch transactions for the user
$sql_transactions = "SELECT wallet_type, amount FROM wallet_transactions WHERE user_id = ?";
$transactionStmt = $conn->prepare($sql_transactions);
$transactionStmt->bind_param("i", $mlmUserId);
$transactionStmt->execute();
$result_transactions = $transactionStmt->get_result();

$total_add = 0;
$total_withdrawal = 0;

if ($result_transactions->num_rows > 0) {
    while ($transaction = $result_transactions->fetch_assoc()) {
        if ($transaction['wallet_type'] == 'add') {
            $total_add += $transaction['amount'];
        } elseif ($transaction['wallet_type'] == 'withdrawal') {
            $total_withdrawal += $transaction['amount'];
        }
    }
}

// Calculate total balance
$total_balance = $total_add - $total_withdrawal;

?>

<div class="appFooter">
    <div class="footer-title">
        Copyright © Balaji Engo 2024. All Rights Reserved.
    </div>
</div>
<!-- * app footer -->

</div>
<!-- * App Capsule -->

<!-- App Bottom Menu -->
<div class="appBottomMenu">
    <a href="index.php" class="item active">
        <div class="col">
            <ion-icon name="pie-chart-outline"></ion-icon>
            <strong>Overview</strong>
        </div>
    </a>
    <a href="" class="item">
        <div class="col">
            <ion-icon name="document-text-outline"></ion-icon>
            <strong>Pages</strong>
        </div>
    </a>
    <a href="index.php" class="item">
        <div class="col">
            <ion-icon name="apps-outline"></ion-icon>
            <strong>Dashboard</strong>
        </div>
    </a>
    <a href="wallet.php" class="item">
        <div class="col">
            <ion-icon name="card-outline"></ion-icon>
            <strong>Wallet</strong>
        </div>
    </a>
    <a class="item">
        <div class="col" data-bs-toggle="modal" data-bs-target="#switchAccountModal">
            <ion-icon name="settings-outline"></ion-icon>
            <strong>Settings</strong>
        </div>
    </a>
</div>
<!-- * App Bottom Menu -->

<div class="modal fade" id="switchAccountModal" tabindex="-1" aria-labelledby="switchAccountModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered" style="max-width: 400px; width: 100%;">
        <div class="modal-content" style="border-radius: 15px; overflow: hidden;">
            <div class="modal-header border-0 p-3" style="justify-content: space-between;">
                <h5 class="modal-title" id="switchAccountModalLabel" style="font-weight: bold;">Switch Account</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body ">
                <form method="post" id="switchAccountForm"> <!-- Form -->
                    <div id="samePhoneUsers" style="max-height: 300px; overflow-y: auto;">
                        <?php if (!empty($samePhoneUsers)): ?>
                            <?php foreach ($samePhoneUsers as $samePhoneUser): ?>
                                <div class="d-flex align-items-center mb-3 user-option" style="padding: 10px 15px; background-color: #fafafa; border-radius: 10px; cursor: pointer;" data-user-id="<?php echo $samePhoneUser['id']; ?>">
                                    <div class="avatar" style="width: 50px; height: 50px; border-radius: 50%; overflow: hidden;">
                                        <img src="https://hum.ujn.mybluehostin.me/mlm/finapp.bragherstudio.com/Gaurav/main/assets/img/logo.png" alt="User Image" style="width: 100%; height: auto;">
                                    </div>
                                    <div class="ms-3" style="flex-grow: 1;">
                                        <label class="form-check-label" style="font-weight: 500; font-size: 16px; cursor: pointer;">
                                            <?php echo htmlspecialchars($samePhoneUser['name']); ?>
                                        </label>
                                        <input type="hidden" name="switch_user_id" value="<?php echo $samePhoneUser['id']; ?>">
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <p>No account exists. Please create a new one.</p>
                        <?php endif; ?>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<!-- Add this script to make clicking on a user switch the account -->
<script>
    // JavaScript to submit the form automatically when a user option is clicked
    document.querySelectorAll('.user-option').forEach(function(userOption) {
        userOption.addEventListener('click', function() {
            const userId = this.getAttribute('data-user-id');
            // Set the hidden input value to the clicked user ID
            document.querySelector('input[name="switch_user_id"]').value = userId;
            // Submit the form
            document.getElementById('switchAccountForm').submit();
        });
    });
</script>












<!-- App Sidebar -->
<div class="modal fade panelbox panelbox-left" id="sidebarPanel" tabindex="-1" role="dialog">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-body p-0">
                <!-- profile box -->
                <div class="profileBox pt-2 pb-2">
                    <div class="image-wrapper">
                        <img src="assets/img/logo.png" alt="image" class="imaged w36">
                    </div>
                    <div class="in">
                        <strong><?php echo $user_name; ?></strong>
                        <div class="text-muted"><?php echo $my_number; ?></div> <!-- Display user's my_number -->
                    </div>
                    <a href="#" class="btn btn-link btn-icon sidebar-close" data-bs-dismiss="modal">
                        <ion-icon name="close-outline"></ion-icon>
                    </a>
                </div>
                <!-- * profile box -->

                <!-- balance -->
                <div class="sidebar-balance">
                    <div class="listview-title">Total Balance</div>
                    <div class="in">
                        <h1 class="amount">$ <?php echo number_format($total_balance, 2); ?></h1> <!-- Show total balance -->
                    </div>
                </div>
                <!-- * balance -->

                <!-- menu -->
                <div class="listview-title mt-1">Menu</div>
                <ul class="listview flush transparent no-line image-listview">
                    <li>
                        <a href="index.php" class="item">
                            <div class="icon-box bg-primary">
                                <ion-icon name="apps-outline"></ion-icon>
                            </div>
                            <div class="in">
                                Dashboard
                            </div>
                        </a>
                    </li>
                 <li>
                        <a href="adduser.php" class="item">
                            <div class="icon-box bg-primary">
                                <ion-icon name="cash-outline"></ion-icon>
                            </div>
                            <div class="in">
                                Add User
                            </div>
                        </a>
                    </li>
                    <li>
                        <a href="reference-by.php" class="item">
                            <div class="icon-box bg-primary">
                                <ion-icon name="code-working-outline"></ion-icon>
                            </div>
                            <div class="in">
                                Reference By
                                <span class="badge badge-primary"></span>
                            </div>
                        </a>
                    </li>
                    <li>
                        <a href="transactions.php" class="item">
                            <div class="icon-box bg-primary">
                                <ion-icon name="cash-outline"></ion-icon>
                            </div>
                            <div class="in">
                                Transaction
                            </div>
                        </a>
                    </li>
                    <li>
                        <a href="wallet.php" class="item">
                            <div class="icon-box bg-primary">
                                <ion-icon name="wallet-outline"></ion-icon>
                            </div>
                            <div class="in">
                                Wallet
                            </div>
                        </a>
                    </li>
                    <li>
                        <a href="withdrawals_req.php" class="item">
                            <div class="icon-box bg-primary">
                                <ion-icon name="cash-outline"></ion-icon>
                            </div>
                            <div class="in">
                                Withdrawal Requests
                            </div>
                        </a>
                    </li>
                    <li>
                        <a href="view-profile.php" class="item">
                            <div class="icon-box bg-primary">
                                <ion-icon name="person-outline"></ion-icon>
                            </div>
                            <div class="in">
                                View Profile
                            </div>
                        </a>
                    </li>
                </ul>
                <!-- * menu -->

            </div> <!-- Close modal-body -->
        </div> <!-- Close modal-content -->
    </div> <!-- Close modal-dialog -->
</div> <!-- Close modal fade -->
<!-- * App Sidebar -->







<!-- ========= JS Files =========  -->
<!-- Bootstrap -->
<script src="assets/js/lib/bootstrap.bundle.min.js"></script>
<!-- Ionicons -->
<script type="module" src="https://unpkg.com/ionicons@5.5.2/dist/ionicons/ionicons.js"></script>
<!-- Splide -->
<script src="assets/js/plugins/splide/splide.min.js"></script>
<!-- Base Js File -->
<script src="assets/js/base.js"></script>
