<?php
session_start();
include 'db.php'; // Include your database connection file

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve data from the form
    $userId = $_POST['user_id'];
    $userName = $_POST['userName'];
    $bankName = $_POST['bankName'];
    $bankNumber = $_POST['bankNumber'];
    $branch = $_POST['branch'];
    $amount = $_POST['withdrawalAmount'];

    // Query to get the user's total balance
    $query = "SELECT SUM(amount) AS total FROM wallet_transactions WHERE user_id = ? AND wallet_type = 'add'";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    $userBalance = $result->fetch_assoc()['total'] ?? 0;

    // Check if the withdrawal conditions are met
    if ($amount <= $userBalance - 200 && $amount >= 100) {
        // Insert withdrawal into the database
        $withdrawalQuery = "INSERT INTO wallet_transactions (user_id, amount, description, created_at, wallet_type, user_name, bank_name, bank_number, branch) VALUES (?, ?, ?, NOW(), 'withdrawal', ?, ?, ?, ?)";
        $description = "Withdrawal of ₹" . $amount;

        // Prepare the statement
        $stmt = $conn->prepare($withdrawalQuery);
        $stmt->bind_param("idsiss", $userId, $amount, $description, $userName, $bankName, $bankNumber, $branch);
        
        // Execute the statement
        if ($stmt->execute()) {
            // Success message
            echo "<script>alert('Withdrawal successful!'); window.location.href = 'wallet.php';</script>";
        } else {
            // Error message
            echo "<script>alert('Error processing withdrawal. Please try again.'); window.location.href = 'wallet.php';</script>";
        }
    } else {
        // Insufficient balance or invalid amount message
        echo "<script>alert('Insufficient balance or invalid amount. Minimum withdrawal: ₹100. Retain at least ₹200 in your balance.'); window.location.href = 'wallet.php';</script>";
    }
} else {
    // Invalid request message
    echo "<script>alert('Invalid request.'); window.location.href = 'wallet.php';</script>";
}
?>


<!-- Withdrawal Modal -->
<div class="modal fade" id="withdrawalModal" tabindex="-1" aria-labelledby="withdrawalModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="withdrawalModalLabel">Withdrawal Details</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form id="withdrawalForm" method="POST"  onsubmit="return validateWithdrawal();">
                    <div class="mb-3">
                        <label for="userName" class="form-label">User Name *</label>
                        <input type="text" class="form-control" id="userName" name="user_name" required>
                    </div>
                    <div class="mb-3">
                        <label for="bankName" class="form-label">Bank Name *</label>
                        <input type="text" class="form-control" id="bankName" name="bank_name" required>
                    </div>
                    <div class="mb-3">
                        <label for="bankNumber" class="form-label">Bank Number *</label>
                        <input type="text" class="form-control" id="bankNumber" name="bank_number" pattern="\d{1,16}" maxlength="16" title="Only digits are allowed. Maximum 16 digits." required>
                        <div id="bankNumberError" class="text-danger" style="display: none;"></div>
                    </div>
                    <div class="mb-3">
                        <label for="branch" class="form-label">Branch *</label>
                        <input type="text" class="form-control" id="branch" name="branch" required>
                    </div>
                    <div class="mb-3">
                        <label for="withdrawalAmount" class="form-label">Withdrawal Amount *</label>
                        <div id="error-message" class="text-danger" style="display: none;"></div>
                        <input type="number" class="form-control" id="withdrawalAmount" name="withdrawal_amount" step="0.01" required>
                    </div>
                    <input type="hidden" name="user_id" value="<?php echo htmlspecialchars($userId); ?>">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                <button type="submit" class="btn btn-primary" form="withdrawalForm">Withdraw</button>
            </div>
        </div>
    </div>
</div>


<script>
    function validateWithdrawal() {
        const withdrawalAmount = parseFloat(document.getElementById('withdrawalAmount').value);
        const netBalance = parseFloat(<?php echo htmlspecialchars($userBalance); ?>); // Ensure you pass the user's balance from PHP
        const bankNumber = document.getElementById('bankNumber').value;

        // Define the minimum balance that must remain after withdrawal
        const minimumBalance = 200;

        // Clear any previous error messages
        const errorMessageElement = document.getElementById('error-message');
        errorMessageElement.style.display = 'none';
        errorMessageElement.innerText = '';

        const bankNumberErrorElement = document.getElementById('bankNumberError');
        bankNumberErrorElement.style.display = 'none';
        bankNumberErrorElement.innerText = '';

        // Check if the user has 200 or less balance
        if (netBalance <= minimumBalance) {
            errorMessageElement.innerText = 'Your balance must be above ₹200.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }

        // Check if the withdrawal amount is less than 100
        if (withdrawalAmount < 100) {
            errorMessageElement.innerText = 'Minimum withdrawal: ₹100.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }
        
        // Check if the withdrawal amount exceeds the available balance minus the minimum balance requirement
        if (withdrawalAmount > (netBalance - minimumBalance)) {
            errorMessageElement.innerText = 'You can only withdraw up to ₹' + (netBalance - minimumBalance) + '.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }

        // Check if the bank number is valid
        const bankNumberPattern = /^\d{1,16}$/;
        if (!bankNumberPattern.test(bankNumber)) {
            bankNumberErrorElement.innerText = 'Bank number must be 1 to 16 digits long and contain only numbers.';
            bankNumberErrorElement.style.display = 'block';
            return false; // Prevent form submission
        }

        return true; // Allow form submission if all validations pass
    }
</script>
