<?php
session_start();
include 'header.php';
include 'db.php';
$user_id = 1; // Change as needed

// Function to get the root user's information
function getUserMyNumber($user_id) {
    global $conn;
    $sql = "SELECT `id`, `my_number`, `total_balance`, `phone` FROM `MLM_users` WHERE `id` = ?";
    $stmt = $conn->prepare($sql);
    
    if ($stmt) {
        $stmt->bind_param('i', $user_id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($row = $result->fetch_assoc()) {
            return $row; 
        } else {
            return null; 
        }
    } else {
        echo "Error preparing statement: " . $conn->error;
        return null;
    }
}

$root_user_info = getUserMyNumber($user_id);
$root_my_number = $root_user_info['my_number'] ?? null;

// Recursive function to get child users based on the refer code
function getChildUsers($refer_code) {
    global $conn;
    $sql = "SELECT u.my_number, r.new_code, r.refer_code FROM MLM_users u
            JOIN refer_table r ON u.my_number = r.refer_code
            WHERE r.refer_code = ? AND u.approved = 1";

    $stmt = $conn->prepare($sql);
    $stmt->bind_param('s', $refer_code);
    $stmt->execute();
    $result = $stmt->get_result();

    $children = [];
    while ($row = $result->fetch_assoc()) {
        // Get the child's new_code to fetch further children
        $row['children'] = getChildUsers($row['new_code']);
        $children[] = $row; 
    }
    return $children;
}

$childUsers = [];
if ($root_my_number) {
    $childUsers = getChildUsers($root_my_number);
}
$conn->close();
?>

<div id="appCapsule">
    <div class="section mt-2 text-center">
        <h1>Add New User</h1>
    </div>
    <div class="section mb-5 p-2">
        <div class="tree-container">
            <div class="root-user">
                <div class="member-view-box">
                    <div class="member-image">
                        <img src="https://static.vecteezy.com/system/resources/thumbnails/019/896/026/small/male-user-avatar-icon-in-black-colors-person-signs-illustration-png.png" alt="User Icon" style="width: 40px; height: 40px;">
                    </div>
                    <div class="member-text"><?php echo htmlspecialchars($root_my_number); ?></div>
                </div>
            </div>

            <div class="child-users-container">
                <div class="child-users">
                    <?php
                    function displayChildUsers($children) {
                        if (empty($children)) {
                            echo '<div>No child users found.</div>';
                            return;
                        }
                        echo '<div class="nested-children">';
                        foreach ($children as $node) {
                            echo '<div class="child-user" onclick="toggleChildren(this)">';
                            echo '<div class="member-image">
                                    <img src="https://static.vecteezy.com/system/resources/thumbnails/019/896/026/small/male-user-avatar-icon-in-black-colors-person-signs-illustration-png.png" alt="User Icon" style="width: 40px; height: 40px;">
                                  </div>';
                            echo '<div class="member-text">' . htmlspecialchars($node['my_number']) . ' (New Code: ' . htmlspecialchars($node['new_code']) . ', Refer Code: ' . htmlspecialchars($node['refer_code']) . ')</div>';
                            echo '</div>'; 
                            
                            // Recursively display child users, keeping them open
                            if (!empty($node['children'])) {
                                echo '<div class="children" style="display: block;">'; // Keep children open
                                displayChildUsers($node['children']);
                                echo '</div>';
                            }
                        }
                        echo '</div>';
                    }

                    displayChildUsers($childUsers);
                    ?>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    function toggleChildren(element) {
        const children = element.nextElementSibling; // Get the next sibling (children div)
        if (children) {
            if (children.style.display === "none") {
                children.style.display = "block"; // Show children
            } else {
                children.style.display = "none"; // Hide children
            }
        }
    }
</script>

<style>
    .tree-container {
        display: flex;
        flex-direction: column;
        align-items: center;
    }

    .root-user {
        margin-bottom: 0;
        position: relative;
        text-align: center;
    }

    .child-users-container {
        display: flex; 
        flex-direction: column;
        align-items: center;
        position: relative;
    }

    .child-users {
        display: flex;
        justify-content: center; 
        width: 100%;
        text-align: center;
    }

    .child-user {
        display: flex;
        flex-direction: column;
        align-items: center;
        position: relative;
        padding: 10px;
        cursor: pointer; 
    }

    .child-user .member-image {
        margin-bottom: 4px;
    }

    .nested-children {
        margin-left: 20px; /* Indentation for child nodes */
        margin-top: 10px;
        display: flex;
        flex-direction: column;
        align-items: center;
    }

    .children {
        margin-left: 20px; /* Indentation for child nodes */
        display: block; /* Keep children open */
    }

    .member-view-box {
        display: flex;
        flex-direction: column;
        align-items: center;
    }

    .member-image {
        margin-bottom: 8px;
    }
</style>
