<?php 


session_start(); 

include 'db.php'; 
include 'header.php';

if (!isset($_SESSION['mlm_user_id'])) {
    echo "You are not logged in.";
    exit;
}

$userId = $_SESSION['mlm_user_id'];


$entries_per_page = 10; 
$page = isset($_GET['page']) ? (int)$_GET['page'] : 
$offset = ($page - 1) * $entries_per_page;

// Get the filter and search inputs from URL parameters
$filter = isset($_GET['filter']) ? $_GET['filter'] : 'all'; // Filter by wallet type ('add', 'withdrawal', or 'all')
$search = isset($_GET['search']) ? $_GET['search'] : ''; // Search keyword

// SQL query to fetch user's wallet transactions with pagination, filter, and search
$query = "SELECT `id`, `user_id`, `amount`, `description`, `created_at`, `wallet_type` 
          FROM `wallet_transactions` 
          WHERE `user_id` = ? ";

// Apply filter for wallet type if not 'all'
if ($filter !== 'all') {
    $query .= "AND `wallet_type` = ? ";
}

// Apply search filter if search is not empty
if (!empty($search)) {
    $query .= "AND (`description` LIKE ? OR `wallet_type` LIKE ?) ";
}

$query .= "ORDER BY `created_at` DESC 
           LIMIT ?, ?";

// Prepare the statement
$stmt = $conn->prepare($query);

// Initialize an array to hold parameter types
$types = 'i'; // user_id is an integer
$params = [$user_id];

// Bind parameters based on filter and search criteria
if ($filter !== 'all') {
    $types .= 's'; // add string type for filter
    $params[] = $filter; // add filter to params
}

if (!empty($search)) {
    $search_term = '%' . $search . '%';
    $types .= 'ss'; // add two string types for search
    $params[] = $search_term; // add search term for description
    $params[] = $search_term; // add search term for wallet_type
}

// Add offset and entries_per_page as integers
$params[] = $offset;
$params[] = $entries_per_page;
$types .= 'ii'; // two integers for offset and entries_per_page

// Bind the parameters dynamically
$stmt->bind_param($types, ...$params);

// Execute the statement
if (!$stmt->execute()) {
    die("Error executing query: " . $stmt->error);
}
$result = $stmt->get_result(); // Get the result set from the prepared statement

// Fetch all transactions
$transactions = $result->fetch_all(MYSQLI_ASSOC); // Fetch associative array

// Get total number of transactions for pagination
$count_query = "SELECT COUNT(*) as total FROM `wallet_transactions` WHERE `user_id` = ?";

// Apply filter for wallet type in the count query if necessary
if ($filter !== 'all') {
    $count_query .= " AND `wallet_type` = ?";
}

// Prepare count statement
$count_stmt = $conn->prepare($count_query);

// Bind parameters for counting
if ($filter !== 'all') {
    $count_stmt->bind_param("is", $user_id, $filter);
} else {
    $count_stmt->bind_param("i", $user_id);
}

$count_stmt->execute();
$count_result = $count_stmt->get_result();
$total_transactions = $count_result->fetch_assoc()['total'];
$total_pages = ceil($total_transactions / $entries_per_page);
?>

<div class="section mt-2">
    <div class="card" style="padding: 20px; margin-top: 80px; margin-bottom: 20px;">
        <div style="display: flex; align-items: center; justify-content: space-between; margin-bottom: 20px;">
            <h4 class="mb-2 fw-bold text-lg mb-0">User Transaction History</h4>
        </div>
        
        <div style="display: flex; gap: 10px; align-items: center; margin-bottom: 20px;"> 
            <form method="GET" action="" id="filterForm" style="display: flex; gap: 10px; align-items: center;">
                <input type="text" name="search" id="searchInput" class="form-control form-control-sm w-auto" placeholder="Search..." value="<?php echo htmlspecialchars($search); ?>" />
                <select name="filter" id="transactionFilter" class="form-select form-select-sm w-auto bg-base border text-secondary-light">
                    <option value="all" <?php if($filter == 'all') echo 'selected'; ?>>All</option>
                    <option value="add" <?php if($filter == 'add') echo 'selected'; ?>>Add</option>
                    <option value="withdrawal" <?php if($filter == 'withdrawal') echo 'selected'; ?>>Withdrawal</option>
                </select>
            </form>
        </div>

        <div class="table-responsive">
            <table class="table bordered-table mb-0">
                <thead>
                    <tr>
                        <th scope="col">S.L</th>
                        <th scope="col">User ID</th>
                        <th scope="col">Description (Transaction Type)</th>
                        <th scope="col">Created At</th>
                        <th scope="col">Amount</th>
                        <th scope="col">Wallet Type</th>
                    </tr>
                </thead>
                <tbody id="transactionTableBody">
    <?php
    $counter = ($page - 1) * $entries_per_page + 1; // Adjust counter for pagination

    if (empty($transactions)): // Check if there are no transactions
        echo "<tr><td colspan='6' class='text-center'>Data not found based on your search or filter criteria.</td></tr>";
    else:
        foreach ($transactions as $transaction) {
            echo "<tr>";
            echo "<td>{$counter}</td>";
            echo "<td>{$transaction['user_id']}</td>";
            echo "<td>{$transaction['description']}</td>";
            echo "<td>{$transaction['created_at']}</td>";
            echo "<td>₹" . number_format($transaction['amount'], 2) . "</td>";
            echo "<td>
                    <span class='px-24 py-4 rounded-pill fw-medium text-sm " . 
                    ($transaction['wallet_type'] == 'add' ? 'bg-wallet-add text-wallet-add' : 'bg-wallet-withdrawal text-wallet-withdrawal') . "'>
                        " . ucfirst($transaction['wallet_type']) . "
                    </span>
                  </td>";
            echo "</tr>";
            $counter++;
        }
    endif;
    ?>
</tbody>

            </table>
        </div>

        <div id="pagination" class="mt-3 d-flex justify-content-center">
            <?php if ($total_pages > 1): ?>
                <ul class="pagination">
                    <?php if ($page > 1): ?>
                        <li class="page-item"><a class="page-link" href="?page=<?php echo $page - 1; ?>&filter=<?php echo $filter; ?>&search=<?php echo $search; ?>">Previous</a></li>
                    <?php endif; ?>
                    
                    <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                        <li class="page-item <?php if ($i == $page) echo 'active'; ?>"><a class="page-link" href="?page=<?php echo $i; ?>&filter=<?php echo $filter; ?>&search=<?php echo $search; ?>"><?php echo $i; ?></a></li>
                    <?php endfor; ?>
                    
                    <?php if ($page < $total_pages): ?>
                        <li class="page-item"><a class="page-link" href="?page=<?php echo $page + 1; ?>&filter=<?php echo $filter; ?>&search=<?php echo $search; ?>">Next</a></li>
                    <?php endif; ?>
                </ul>
            <?php endif; ?>
        </div>
    </div>
</div>

<style>
    .text-wallet-withdrawal {
        color: #c62828 !important; 
    }

    .text-wallet-add {
        color: #00796b !important;
    }
</style>

<script>
// Debounce function to delay the execution of the search
let debounceTimer;

document.getElementById('searchInput').addEventListener('input', function() {
    clearTimeout(debounceTimer);
    debounceTimer = setTimeout(function() {
        document.getElementById('filterForm').submit();
    }, 300); // Delay of 300 milliseconds
});

document.getElementById('transactionFilter').addEventListener('change', function() {
    document.getElementById('filterForm').submit();
});
</script>

<?php 
include 'footer.php'; 
?>
