<?php 


session_start(); 

include 'db.php'; 
include 'header.php';


$user_id = $_SESSION['user_id'];


$entries_per_page = 10; // Show 10 entries per page
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1; // Get current page, default to 1
$offset = ($page - 1) * $entries_per_page; // Calculate offset

// Get the filter and search inputs from URL parameters
$filter = isset($_GET['filter']) ? $_GET['filter'] : 'all'; // Filter by wallet type ('add', 'withdrawal', or 'all')
$search = isset($_GET['search']) ? $_GET['search'] : ''; // Search keyword

// SQL query to fetch user's wallet transactions with pagination, filter, and search
$query = "SELECT `id`, `user_id`, `amount`, `description`, `created_at`, `wallet_type` 
          FROM `wallet_transactions` 
          WHERE `user_id` = ? ";

// Apply filter for wallet type if not 'all'
if ($filter !== 'all') {
    $query .= "AND `wallet_type` = ? ";
}

// Apply search filter if search is not empty
if (!empty($search)) {
    $query .= "AND (`description` LIKE ? OR `wallet_type` LIKE ?) ";
}

$query .= "ORDER BY `created_at` DESC 
           LIMIT ?, ?";

// Prepare the statement
$stmt = $conn->prepare($query);

// Initialize an array to hold parameter types
$types = 'i'; // user_id is an integer
$params = [$user_id];

// Bind parameters based on filter and search criteria
if ($filter !== 'all') {
    $types .= 's'; // add string type for filter
    $params[] = $filter; // add filter to params
}

if (!empty($search)) {
    $search_term = '%' . $search . '%';
    $types .= 'ss'; // add two string types for search
    $params[] = $search_term; // add search term for description
    $params[] = $search_term; // add search term for wallet_type
}

// Add offset and entries_per_page as integers
$params[] = $offset;
$params[] = $entries_per_page;
$types .= 'ii'; // two integers for offset and entries_per_page

// Bind the parameters dynamically
$stmt->bind_param($types, ...$params);

// Execute the statement
if (!$stmt->execute()) {
    die("Error executing query: " . $stmt->error);
}
$result = $stmt->get_result(); // Get the result set from the prepared statement

// Fetch all transactions
$transactions = $result->fetch_all(MYSQLI_ASSOC); // Fetch associative array

// Get total number of transactions for pagination
$count_query = "SELECT COUNT(*) as total FROM `wallet_transactions` WHERE `user_id` = ?";

// Apply filter for wallet type in the count query if necessary
if ($filter !== 'all') {
    $count_query .= " AND `wallet_type` = ?";
}

// Prepare count statement
$count_stmt = $conn->prepare($count_query);

// Bind parameters for counting
if ($filter !== 'all') {
    $count_stmt->bind_param("is", $user_id, $filter);
} else {
    $count_stmt->bind_param("i", $user_id);
}

$count_stmt->execute();
$count_result = $count_stmt->get_result();
$total_transactions = $count_result->fetch_assoc()['total'];
$total_pages = ceil($total_transactions / $entries_per_page);
?>

<div class="section mt-2">
    <div class="card" style="padding: 20px; margin-top: 140px; margin-bottom: 20px;">
        <div style="display: flex; align-items: center; justify-content: space-between; margin-bottom: 20px;">
            <h4 class="mb-2 fw-bold text-lg mb-0">User Transaction History</h4>
        </div>
        
        <div style="display: flex; gap: 10px; align-items: center; margin-bottom: 20px;"> 
            <form method="GET" action="" id="filterForm" style="display: flex; gap: 10px; align-items: center;">
                <input type="text" name="search" id="searchInput" class="form-control" placeholder="Search..." value="<?php echo htmlspecialchars($search); ?>" />
                <select name="filter" id="transactionFilter" class="form-select form-select-sm w-auto bg-base border text-secondary-light">
                    <option value="all" <?php if($filter == 'all') echo 'selected'; ?>>All</option>
                    <option value="add" <?php if($filter == 'add') echo 'selected'; ?>>Add</option>
                    <option value="withdrawal" <?php if($filter == 'withdrawal') echo 'selected'; ?>>Withdrawal</option>
                </select>
            </form>
        </div>

<div class="transactions">
    <?php
    if (empty($transactions)): // Check if there are no transactions
        echo "<div class='text-center'>Data not found based on your search or filter criteria.</div>";
    else:
        foreach ($transactions as $transaction):
    ?>
        <!-- Transaction Item -->
        <a href="app-transaction-detail.html" class="item">
            <div class="detail">
                <?php if($transaction['wallet_type'] == "add" && $transaction['amount'] == "50.00" ){ ?>
                <img src="assets/img/25.png" alt="img" class="image-block imaged w48"> 
                <?php }else if($transaction['wallet_type'] == "add" && $transaction['amount'] == "10.00" ){ ?>
                <img src="assets/img/5.png" alt="img" class="image-block imaged w48"> 
                <?php }else if($transaction['wallet_type'] == "withdrawal"  ){ ?>
                <img src="assets/img/Withdrawals.png" alt="img" class="image-block imaged w48"> 
                <?php }else if($transaction['wallet_type'] == "bonus"  ){ ?>
                <img src="assets/img/bonus.png" alt="img" class="image-block imaged w48"> 
                <?php } ?>
                <div>
                    <strong><?php echo htmlspecialchars($transaction['description']); ?></strong>
                    <p><?php echo htmlspecialchars($transaction['wallet_type'] == "add" ? "added" : $transaction['wallet_type']); ?></p>
                </div>
            </div>
            <div class="right">
                <div class="price <?php echo ($transaction['wallet_type'] == 'add') ? 'text-success' : 'text-danger'; ?>">
                    <?php echo  ' ₹' . number_format(abs($transaction['amount']), 2); ?>
                </div>
            </div>
        </a>
    <?php
        endforeach;
    endif;
    ?>
</div>

        <div id="pagination" class="mt-3 d-flex justify-content-center">
    <?php if ($total_pages > 1): ?>
        <ul class="pagination" style="list-style: none; padding: 0; display: flex; gap: 10px;">
            <?php if ($page > 1): ?>
                <li class="page-item">
                    <a class="page-link" 
                       href="?page=<?php echo $page - 1; ?>&filter=<?php echo $filter; ?>&search=<?php echo $search; ?>"
                       style="width: 35px; height: 35px; display: flex; align-items: center; justify-content: center;
                              border-radius: 50%; text-decoration: none; background-color: #ffffff; 
                              color: #438fcd; border: 1px solid #438fcd;">
                       &lt;
                    </a>
                </li>
            <?php endif; ?>
            
            <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                <li class="page-item <?php if ($i == $page) echo 'active'; ?>">
                    <a class="page-link" 
                       href="?page=<?php echo $i; ?>&filter=<?php echo $filter; ?>&search=<?php echo $search; ?>"
                       style="width: 35px; height: 35px; display: flex; align-items: center; justify-content: center;
                              border-radius: 50%; text-decoration: none; 
                              background-color: <?php echo $i == $page ? '#438fcd' : '#ffffff'; ?>;
                              color: <?php echo $i == $page ? '#fff' : '#438fcd'; ?>; 
                              border: 1px solid #438fcd;">
                       <?php echo $i; ?>
                    </a>
                </li>
            <?php endfor; ?>
            
            <?php if ($page < $total_pages): ?>
                <li class="page-item">
                    <a class="page-link" 
                       href="?page=<?php echo $page + 1; ?>&filter=<?php echo $filter; ?>&search=<?php echo $search; ?>"
                       style="width: 35px; height: 35px; display: flex; align-items: center; justify-content: center;
                              border-radius: 50%; text-decoration: none; background-color: #ffffff; 
                              color: #438fcd; border: 1px solid #438fcd;">
                       &gt;
                    </a>
                </li>
            <?php endif; ?>
        </ul>
    <?php endif; ?>
</div>

    </div>
</div>

<style>
    .text-wallet-withdrawal {
        color: #c62828 !important; 
    }

    .text-wallet-add {
        color: #00796b !important;
    }
</style>

<script>
// Debounce function to delay the execution of the search
let debounceTimer;

document.getElementById('searchInput').addEventListener('input', function() {
    clearTimeout(debounceTimer);
    debounceTimer = setTimeout(function() {
        document.getElementById('filterForm').submit();
    }, 300); // Delay of 300 milliseconds
});

document.getElementById('transactionFilter').addEventListener('change', function() {
    document.getElementById('filterForm').submit();
});
</script>

<?php 
include 'footer.php'; 
?>
