<?php
session_start(); // Ensure session is started
include 'header.php'; 

// Check if mlm_user_id is set
if (!isset($_SESSION['mlm_user_id'])) {
    echo "You are not logged in.";
    exit;
}

// Assuming a database connection is established here
include 'db.php'; // Adjust the file name as necessary

// Fetch user details based on mlm_user_id
$mlm_user_id = $_SESSION['mlm_user_id'];
$query = "SELECT `id`, `u_id`, `name`, `phone`, `reference_number` FROM `MLM_users` WHERE `id` = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $mlm_user_id);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

// Initialize a message variable
$message = '';

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get values from the form
    $new_user_name = $_POST['name'];
    $reference_number = $_POST['reference_code']; // This is the reference code from the readonly field
    $u_id = $user['u_id']; // Existing user ID from the fetched data
    $phone = $user['phone']; // Existing phone number from the fetched data

    // Prepare the insert query
    $insert_query = "INSERT INTO `MLM_users` (`u_id`, `name`, `phone`, `reference_number`, `my_number`, `total_balance`, `approved`) VALUES (?, ?, ?, ?, '', 0, 0)";
    $insert_stmt = $conn->prepare($insert_query);
    $insert_stmt->bind_param("ssss", $u_id, $new_user_name, $phone, $reference_number);
    
    // Execute the insertion
    if ($insert_stmt->execute()) {
        $message = "User added successfully."; // Set the success message
    } else {
        $message = "Error adding user: " . $conn->error; // Set the error message
    }
}

?>

<div id="appCapsule">
    <div class="section mt-2 text-center">
        <h1>Add New User</h1>
    </div>
    <div class="section mb-5 p-2">
        <div class="row justify-content-center align-items-center">
            <!-- Display User Details -->

            <!-- Edit Profile Form Column -->
            <div class="col-12 col-md-6 mb-4">
                <form action="" method="POST" class="w-100">
                    <div class="card">
                        <div class="card-body">
                            <div class="message">
                                <!-- Display any messages here -->
                                <?php if ($message): ?>
                                    <div class="alert alert-info"><?php echo htmlspecialchars($message); ?></div>
                                <?php endif; ?>
                            </div>

                            <div class="form-group basic">
                                <div class="input-wrapper">
                                    <label class="label" for="reference_code">Reference Code</label>
                                    <input type="text" class="form-control" id="reference_code" name="reference_code" 
                                    value="<?php echo htmlspecialchars($user['reference_number']); ?>" readonly>
                                </div>
                            </div>

                            <!-- User Name Field -->
                            <div class="form-group basic">
                                <div class="input-wrapper">
                                    <label class="label" for="name">User Name</label>
                                    <input type="text" class="form-control" id="name" name="name" placeholder="Your Name" required>
                                </div>
                            </div>

                            <div class="form-top-group">
                                <button type="submit" class="btn btn-primary btn-block btn-lg">Add User</button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<?php 
include 'footer.php'; 
?>
