<?php
include 'db.php'; // Include the database connection file
session_start(); 

// Get the mobile number from the URL parameters
$mobileNumber = isset($_GET['mobile']) ? $_GET['mobile'] : null;

// Check if mobile number is provided
if ($mobileNumber) {
    // Prepare a statement to check if the mobile number exists
    $stmt = $conn->prepare("SELECT `id` FROM `MLM_users` WHERE `phone` = ?");
    $stmt->bind_param("s", $mobileNumber);
    $stmt->execute();
    $stmt->store_result();

    // If the mobile number exists, fetch the user ID and store it in the session
    if ($stmt->num_rows > 0) {
        $stmt->bind_result($userId); // Bind the user ID to a variable
        $stmt->fetch(); // Fetch the user ID from the result
        $_SESSION['user_id'] = $userId; // Store user ID in session
        $_SESSION['mobile_number'] = $mobileNumber; // Store mobile number in session

        // Redirect to index.php
        header("Location: index.php");
        exit();
    }

    $stmt->close();
} else {
    // If no mobile number is provided, handle the error accordingly (optional)
    echo "Mobile number is required.";
    exit();
}

// Handle the registration form submission
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $name = $_POST['name'];
    $reference = $_POST['reference'] ?? null;
    $password = password_hash($_POST['password'], PASSWORD_DEFAULT); // Hash the password for security

    // Prepare a statement to insert the new user
    $stmt = $conn->prepare("INSERT INTO `MLM_users` (`phone`, `name`, `reference_number`, `password`, `created_at`) VALUES (?, ?, ?, ?, NOW())");
    $stmt->bind_param("ssss", $mobileNumber, $name, $reference, $password);
    
    if ($stmt->execute()) {
        // If the user is successfully registered, get the user ID and redirect
        $userId = $stmt->insert_id; // Get the last inserted ID

        // Store user ID and mobile number in the session
        $_SESSION['user_id'] = $userId; // Store user ID in session
        $_SESSION['mobile_number'] = $mobileNumber; // Store mobile number in session

        // Redirect to index.php
        header("Location: index.php");
        exit();
    } else {
        echo "Error: " . $stmt->error; // Handle registration errors
    }
    $stmt->close();
}
?>


<!doctype html>
<html lang="en">
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1, maximum-scale=1, viewport-fit=cover" />
    <meta name="mobile-web-app-capable" content="yes" />
    <meta name="mobile-web-app-status-bar-style" content="black-translucent">
    <meta name="theme-color" content="#000000">
    <title>Finapp Registration</title>
    <link rel="icon" type="image/png" href="assets/img/favicon.png" sizes="32x32">
    <link rel="stylesheet" href="assets/css/style.css">
    <style>
        .form-button-group {
            margin-top: 20px;
        }
        .input-prefix {
            display: flex;
            align-items: center;
        }
        .input-prefix span {
            margin-right: 10px;
        }
    </style>
</head>

<body>
    <div id="appCapsule">
        <div class="section mt-2 text-center">
            <h1>Complete Your Registration</h1>
            <h4>Welcome! Please fill in the details below.</h4>
        </div>

        <div class="section mb-5 p-2">
            <form id="registrationForm" action="" method="POST">
                <div class="card">
                    <div class="card-body">
                        <!-- Mobile Number Input Field -->
                        <div class="form-group basic">
                            <div class="input-wrapper">
                                <label class="label">Mobile Number</label>
                                <div class="input-prefix">
                                    <span>+91</span>
                                    <input type="tel" class="form-control" id="mobile" name="mobile" placeholder="Enter Mobile Number" value="<?php echo htmlspecialchars($mobileNumber); ?>" required readonly>
                                </div>
                            </div>
                        </div>

                        <!-- Name Input Field -->
                        <div class="form-group basic">
                            <div class="input-wrapper">
                                <label class="label" for="name">Enter Your Name</label>
                                <input type="text" class="form-control" id="name" name="name" placeholder="Enter Your Name" required>
                            </div>
                        </div>

                        <!-- Reference Code Input Field -->
                        <div class="form-group basic">
                            <div class="input-wrapper">
                                <label class="label" for="reference">Reference Code (Optional)</label>
                                <input type="text" class="form-control" id="reference" name="reference" placeholder="Enter Reference Code">
                            </div>
                        </div>

                        <!-- Password Input Field -->
                        <div class="form-group basic">
                            <div class="input-wrapper">
                                <label class="label" for="password">Create Password</label>
                                <input type="password" class="form-control" id="password" name="password" placeholder="Create Password" required>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Button to Submit Registration -->
                <div class="form-button-group transparent">
                    <button type="submit" class="btn btn-primary btn-block btn-lg">Register</button>
                </div>
            </form>
        </div>
    </div>

    <script>
        // Get the mobile number from the URL parameters if needed (optional)
        const urlParams = new URLSearchParams(window.location.search);
        const mobileNumber = urlParams.get('mobile');
        if (mobileNumber) {
            // Only set the value if the mobile number is provided
            document.getElementById('mobile').value = mobileNumber.replace(/^(\+91)?/, ''); // Remove the +91 prefix if present
        }
    </script>
</body>
</html>
