<?php
session_start(); // Ensure session is started
include 'header.php';
include 'db.php';

// Initialize user_id variable (assuming it's retrieved from the session)
$user_id = $_SESSION['user_id'] ?? null; // Retrieve user_id from session or set to null


$user_id = 120;
// Function to get user my_number and total_balance
function getUserMyNumber($user_id)
{
    global $conn;
    $sql = "SELECT `my_number`, `total_balance` FROM `MLM_users` WHERE `id` = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param('i', $user_id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($row = $result->fetch_assoc()) {
        return $row; // Return the entire row with my_number and total_balance
    }
    return null;
}

// Get the user's my_number and total_balance if found
$root_user_info = getUserMyNumber($user_id);
$root_my_number = $root_user_info['my_number'] ?? null;
$root_total_balance = $root_user_info['total_balance'] ?? null;

// Function to get user data recursively
function getUserData($reference_number, &$userCount)
{
    global $conn;

    // Limit the number of users to 120
    if ($userCount >= 120) {
        return [];
    }

    $sql = "SELECT `id`, `name`, `phone`, `reference_number`, `my_number`, `created_at`, `total_balance`, `approved` FROM `MLM_users` WHERE `reference_number` = ? AND `approved` = 1";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param('s', $reference_number);
    $stmt->execute();
    $result = $stmt->get_result();

    $children = [];
    while ($row = $result->fetch_assoc()) {
        $userCount++; // Increment user count
        if ($userCount > 120) break; // Stop if count exceeds 120

        $row['children'] = getUserData($row['my_number'], $userCount); // Recursive call to get children
        $children[] = $row;
    }
    return $children;
}

// Initialize tree data
$treeData = [];
$userCount = 0; // Initialize user count
if ($root_my_number) {
    $treeData = getUserData($root_my_number, $userCount);
}

$conn->close();
?>

<div class="dashboard-main-body">
        <div class="d-flex flex-wrap align-items-center justify-content-between gap-3" style="margin-bottom: 3.5rem;">
            <h6 class="fw-semibold mb-0">Reference By  </h6>
           
            <ul class="d-flex align-items-center gap-2">
                <li class="fw-medium">
                    <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                        <i class="fas fa-home"></i>
                        Dashboard
                    </a>
                </li>
                <li>-</li>
                <li class="fw-medium">Reference By</li>
            </ul>
        </div>
        <div class="row gy-4" style=" background-color: white; padding-bottom: 50px; "  >
        <div class="col-lg-12" >
            <div>

            <div class="scrollable-tree-container"> 
                    <div class="tree" style="overflow: auto;">

                        <style>
                            .member-image {
                                transition: transform 0.3s ease;
                            }

                            .member-image:hover {
                                transform: scale(1.2);
                            }
                        </style>

                        <?php
                        // Recursive function to display the tree
                        function displayTree($data, $isRoot = false)
                        {
                            if (empty($data)) {
                                return; // Exit if there's no data
                            }

                            echo '<ul>';
                            foreach ($data as $node) {
                                echo '<li>';
                                // Check if this node is the root node
                                $rootClass = $isRoot ? 'root-member' : '';
                                echo '<div class="' . $rootClass . '" data-id="' . htmlspecialchars($node['my_number']) . '">';
                                echo '<div class="member-image" data-effect="zoom"><img src="https://static.vecteezy.com/system/resources/thumbnails/019/896/026/small/male-user-avatar-icon-in-black-colors-person-signs-illustration-png.png" alt="User Icon"></div>';
                                echo '<div class="member-text">' . htmlspecialchars($node['my_number']) . '</div>';
                                echo '</div>'; // Close member-view-box

                                // Recursive call to display children
                                displayTree($node['children'], false);
                                echo '</li>';
                            }
                            echo '</ul>';
                        }

                        // Display the root user as part of the tree if found
                        if ($root_my_number) {
                            $rootData = [
                                [
                                    'my_number' => $root_my_number,
                                    'reference_number' => '', // Assuming root doesn't have a reference number
                                    'total_balance' => $root_total_balance, // Include total balance
                                    'children' => $treeData
                                ]
                            ];
                            displayTree($rootData, true);
                        } else {
                            echo "<div>No user found.</div>"; // Display if no user found
                        }
                        ?>
                    </div>
                </div>
                </div>
               
            </div>
        </div>


        <script>
            document.querySelectorAll('.member-view-box').forEach(box => {
                box.addEventListener('click', function() {
                    // Remove highlight from all boxes
                    document.querySelectorAll('.member-view-box').forEach(b => {
                        b.classList.remove('highlight');
                    });

                    // Highlight the clicked box
                    this.classList.add('highlight');

                    // Optionally, handle other click actions here
                    console.log("User ID:", this.getAttribute('data-id'));
                });
            });
        </script>

</div>




<style>
    * {
        margin: 0;
        padding: 0;
    }

    .scrollable-tree-container {
        overflow-x: auto;
        /* Enable horizontal scrolling */
        width: 100%;
        /* Full width of the container */
        display: flex;
        /* Use flexbox for better alignment */
    }

    .tree {
        display: flex;
        /* Use flexbox for horizontal layout */
    }

    .tree ul {
        display: flex;
        /* Use flexbox for inline list items */
        padding: 0;
        /* Remove padding for better alignment */
        margin: 0;
        /* Remove margin for better alignment */
        list-style: none;
        /* Remove bullets */
    }

    .tree li {
        float: left;
        text-align: center;
        list-style-type: none;
        position: relative;
        padding: 20px 5px 0 5px;
        transition: all 0.5s;
    }

    .tree li::before,
    .tree li::after {
        content: '';
        position: absolute;
        top: 0;
        right: 50%;
        border-top: 1px solid #ccc;
        width: 50%;
        height: 20px;
    }

    .tree li::after {
        right: auto;
        left: 50%;
        border-left: 1px solid #ccc;
    }

    .tree li:only-child::after,
    .tree li:only-child::before {
        display: none;
    }

    .tree li:only-child {
        padding-top: 0;
    }

    .tree li:first-child::before,
    .tree li:last-child::after {
        border: 0 none;
    }

    .tree li:last-child::before {
        border-right: 1px solid #ccc;
        border-radius: 0 5px 0 0;
    }

    .tree li:first-child::after {
        border-radius: 5px 0 0 0;
    }

    .tree ul ul::before {
        content: '';
        position: absolute;
        top: 0;
        left: 50%;
        border-left: 1px solid #ccc;
        width: 0;
        height: 20px;
    }

    .tree li a {
        border: 1px solid #ccc;
        padding: 5px 10px;
        text-decoration: none;
        color: #666;
        font-family: Arial, Verdana, Tahoma;
        font-size: 11px;
        display: inline-block;
        border-radius: 5px;
        transition: all 0.5s;
    }

    .tree li a:hover,
    .tree li a:hover+ul li a {
        background: #c8e4f8;
        color: #000;
        border: 1px solid #94a0b4;
    }

    .tree li a:hover+ul li::after,
    .tree li a:hover+ul li::before,
    .tree li a:hover+ul::before,
    .tree li a:hover+ul ul::before {
        border-color: #94a0b4;
    }

    .member-view-box {
        background: #f9f9f9;
        border: 1px solid #ccc;
        border-radius: 5px;
        padding: 10px;
        width: 150px;
        display: inline-block;
        cursor: pointer;
    }

    .member-image img {
        width: 30px;
        height: 30px;
        border-radius: 50%;
    }

    .member-text {
        font-size: 10px;
    }

    .highlight {
        background-color: #d1e7dd;
    }
</style>

  

        <?php include 'footer.php'; ?>