<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

session_start();
include 'header.php'; 
include 'db.php'; 



// Get user data from the database
$query = "SELECT id, name, phone, reference_number, my_number, created_at, total_balance, approved FROM MLM_users WHERE id = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo "<p>User not found.</p>";
    exit;
}

// Initialize a message variable
$message = '';

// Update user profile if form is submitted
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $updated_name = trim($_POST['name']);
    $updated_phone = trim($_POST['phone']);

    // Validate input
    if (empty($updated_name) || empty($updated_phone)) {
        $message = "<p class='text-danger'>Please fill in all fields.</p>";
    } else {
        // Update user info in the database
        $update_query = "UPDATE MLM_users SET name = ?, phone = ? WHERE id = ?";
        $update_stmt = $conn->prepare($update_query);
        $update_stmt->bind_param("ssi", $updated_name, $updated_phone, $user_id);

        if ($update_stmt->execute()) {
            $message = "<p class='text-success'>Profile updated successfully.</p>";
            // Refresh the user data after update
            $user['name'] = $updated_name;
            $user['phone'] = $updated_phone;
        } else {
            $message = "<p class='text-danger'>Error updating profile. Please try again.</p>";
        }
    }
}
?>

<div class="dashboard-main-body">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0">View Profile</h6>
        <ul class="d-flex align-items-center gap-2">
            <li class="fw-medium">
                <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                    <iconify-icon icon="solar:home-smile-angle-outline" class="icon text-lg"></iconify-icon>
                    Dashboard
                </a>
            </li>
            <li>-</li>
            <li class="fw-medium">View Profile</li>
        </ul>
    </div>

    <div class="row gy-4">
        <div class="col-lg-6">
            <div class="user-grid-card position-relative border radius-16 overflow-hidden bg-base h-100">
                <div class="pb-24 ms-16 mb-24 ">
                    
                    <div class="mt-24">
                        <h6 class="text-xl mb-16">Personal Info</h6>
                        <ul>
                            <li class="d-flex align-items-center gap-1 mb-12">
                                <span class="w-30 text-md fw-semibold text-primary-light">Full Name</span>
                                <span class="w-70 text-secondary-light fw-medium">: <?php echo htmlspecialchars($user['name']); ?></span>
                            </li>
                            <li class="d-flex align-items-center gap-1 mb-12">
                                <span class="w-30 text-md fw-semibold text-primary-light">Phone Number</span>
                                <span class="w-70 text-secondary-light fw-medium">: <?php echo htmlspecialchars($user['phone']); ?></span>
                            </li>
                            <li class="d-flex align-items-center gap-1 mb-12">
                                <span class="w-30 text-md fw-semibold text-primary-light">Reference Number</span>
                                <span class="w-70 text-secondary-light fw-medium">: <?php echo htmlspecialchars($user['reference_number']); ?></span>
                            </li>
                            <li class="d-flex align-items-center gap-1 mb-12">
                                <span class="w-30 text-md fw-semibold text-primary-light">My Number</span>
                                <span class="w-70 text-secondary-light fw-medium">: <?php echo htmlspecialchars($user['my_number']); ?></span>
                            </li>
                            <li class="d-flex align-items-center gap-1 mb-12">
                                <span class="w-30 text-md fw-semibold text-primary-light">Created At</span>
                                <span class="w-70 text-secondary-light fw-medium">: <?php echo htmlspecialchars($user['created_at']); ?></span>
                            </li>
                            <li class="d-flex align-items-center gap-1 mb-12">
                                <span class="w-30 text-md fw-semibold text-primary-light">Total Balance</span>
                                <span class="w-70 text-secondary-light fw-medium">: $<?php echo htmlspecialchars($user['total_balance']); ?></span>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>

        <div class="col-lg-6">
            <div class="card h-100">
                <div class="card-body p-24">
                    <h6 class="text-xl mb-16">Edit Profile</h6>
                    <?php if ($message): ?>
                        <div><?php echo $message; ?></div> <!-- Display the message -->
                    <?php endif; ?>
                    <form method="POST">
                        <div class="row">
                                <div class="mb-20">
                                    <label for="name" class="form-label fw-semibold text-primary-light text-sm mb-8">Full Name <span class="text-danger-600">*</span></label>
                                    <input type="text" class="form-control radius-8" id="name" name="name" value="<?php echo htmlspecialchars($user['name']); ?>" required>
                                </div>

                                <div class="mb-20">
                                    <label for="phone" class="form-label fw-semibold text-primary-light text-sm mb-8">Phone <span class="text-danger-600">*</span></label>
                                    <input type="text" class="form-control radius-8" id="phone" name="phone" value="<?php echo htmlspecialchars($user['phone']); ?>" required>
                                </div>
                        </div>
                        <div class="d-flex align-items-center justify-content-center gap-3">

                            <button type="submit" class="btn btn-primary border border-primary-600 text-md px-56 py-12 radius-8"> 
                                Save
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include 'footer.php'; // Include your footer file ?>
